@@ -1,11 +1,22 @@
 #[macro_export]
 macro_rules! println_with_prefix {
     ($($arg:tt)+) => {
-        eprint!("\u{001b}[1m[systemd-boot-friend]\u{001b}[0m ");
+        eprint!("{}", console::style("[systemd-boot-friend] ").bold());
         eprintln!($($arg)+);
     };
 }
 
+#[macro_export]
+macro_rules! println_with_fl {
+    ($message_id:literal) => {
+        eprintln!("{}", fl!($message_id))
+    };
+
+    ($message_id:literal, $($args:expr), *) => {
+        eprintln!("{}", fl!($message_id, $($args), *))
+    }
+}
+
 #[macro_export]
 macro_rules! print_block_with_fl {
     ($message_id:literal) => {
