@@ -235,16 +235,13 @@ fn list_installed<K: Kernel>(installed_kernels: &[Rc<K>]) {
 
 /// Ask for the timeout of systemd-boot boot menu
 fn ask_set_timeout(timeout: Option<u32>, sbconf: Rc<RefCell<SystemdBootConf>>) -> Result<()> {
-    if let Some(t) = timeout {
-        sbconf.borrow_mut().config.timeout = Some(t);
-    } else {
-        sbconf.borrow_mut().config.timeout = Some(
-            Input::with_theme(&ColorfulTheme::default())
-                .with_prompt(fl!("input_timeout"))
-                .default(5u32)
-                .interact()?,
-        );
-    }
+    sbconf.borrow_mut().config.timeout = timeout.or_else(|| {
+        Input::with_theme(&ColorfulTheme::default())
+            .with_prompt(fl!("input_timeout"))
+            .default(5u32)
+            .interact()
+            .ok()
+    });
     sbconf.borrow().write_config()?;
 
     Ok(())
@@ -263,11 +260,10 @@ fn main() -> Result<()> {
         return Ok(());
     }
 
-    let sbconf = Rc::new(RefCell::new(SystemdBootConf::new(
-        &config.esp_mountpoint.join("loader/"),
-        libsdbootconf::Config::default(),
-        Vec::new(),
-    )));
+    let sbconf = Rc::new(RefCell::new(
+        SystemdBootConf::load(&config.esp_mountpoint.join("loader/"))
+            .map_err(|_| anyhow!(fl!("info_path_not_exist")))?,
+    ));
     let installed_kernels = GenericKernel::list_installed(&config, sbconf.clone())?;
     let kernels = GenericKernel::list(&config, sbconf.clone())?;
 
